from setuptools import setup
setup(name='pygger',
version='0.214',
description='Swagger doc generator for python code',
url='https://github.com/GBernard314/pygger',
author='GBernard314',
author_email='guillaume.bernard31415@gmail.com',
license='MIT',
packages=['objects'],
zip_safe=False)